@@ -193,8 +193,12 @@ func TestUpdateDefaultIngressController(t *testing.T) {
 		t.Fatalf("failed to observe expected conditions: %v", err)
 	}
 
-	configmap := &corev1.ConfigMap{}
-	if err := kclient.Get(context.TODO(), controller.RouterCAConfigMapName(), configmap); err != nil {
+	routerCAConfigmap := &corev1.ConfigMap{}
+	if err := kclient.Get(context.TODO(), controller.RouterCAConfigMapName(), routerCAConfigmap); err != nil {
+		t.Fatalf("failed to get CA certificate configmap: %v", err)
+	}
+	defaultIngressCAConfigmap := &corev1.ConfigMap{}
+	if err := kclient.Get(context.TODO(), controller.DefaultIngressCertConfigMapName(), defaultIngressCAConfigmap); err != nil {
 		t.Fatalf("failed to get CA certificate configmap: %v", err)
 	}
 
@@ -245,7 +249,7 @@ func TestUpdateDefaultIngressController(t *testing.T) {
 
 	// Wait for the CA certificate configmap to be deleted.
 	err = wait.PollImmediate(1*time.Second, 10*time.Second, func() (bool, error) {
-		if err := kclient.Get(context.TODO(), controller.RouterCAConfigMapName(), configmap); err != nil {
+		if err := kclient.Get(context.TODO(), controller.RouterCAConfigMapName(), routerCAConfigmap); err != nil {
 			if errors.IsNotFound(err) {
 				return true, nil
 			}
@@ -256,6 +260,20 @@ func TestUpdateDefaultIngressController(t *testing.T) {
 	if err != nil {
 		t.Fatalf("failed to observe clean-up of CA certificate configmap: %v", err)
 	}
+	// Wait for the default ingress configmap to be updated
+	previousDefaultIngressCAConfigmap := defaultIngressCAConfigmap.DeepCopy()
+	err = wait.PollImmediate(1*time.Second, 10*time.Second, func() (bool, error) {
+		if err := kclient.Get(context.TODO(), controller.DefaultIngressCertConfigMapName(), defaultIngressCAConfigmap); err != nil {
+			return false, err
+		}
+		if defaultIngressCAConfigmap.Data["ca-bundle.crt"] == previousDefaultIngressCAConfigmap.Data["ca-bundle.crt"] {
+			return false, nil
+		}
+		return true, nil
+	})
+	if err != nil {
+		t.Fatalf("failed to observe update of default ingress CA certificate configmap: %v", err)
+	}
 
 	// Reset .spec.defaultCertificate to its original value.
 	if err := kclient.Get(context.TODO(), defaultName, ic); err != nil {
@@ -268,7 +286,7 @@ func TestUpdateDefaultIngressController(t *testing.T) {
 
 	// Wait for the CA certificate configmap to be recreated.
 	err = wait.PollImmediate(1*time.Second, 10*time.Second, func() (bool, error) {
-		if err := kclient.Get(context.TODO(), controller.RouterCAConfigMapName(), configmap); err != nil {
+		if err := kclient.Get(context.TODO(), controller.RouterCAConfigMapName(), routerCAConfigmap); err != nil {
 			if !errors.IsNotFound(err) {
 				t.Logf("failed to get CA certificate configmap, will retry: %v", err)
 			}
@@ -279,6 +297,21 @@ func TestUpdateDefaultIngressController(t *testing.T) {
 	if err != nil {
 		t.Fatalf("failed to get recreated CA certificate configmap: %v", err)
 	}
+	// Wait for the default ingress configmap to be updated back to the original
+	previousDefaultIngressCAConfigmap = defaultIngressCAConfigmap.DeepCopy()
+	err = wait.PollImmediate(1*time.Second, 10*time.Second, func() (bool, error) {
+		if err := kclient.Get(context.TODO(), controller.DefaultIngressCertConfigMapName(), defaultIngressCAConfigmap); err != nil {
+			return false, err
+		}
+		if defaultIngressCAConfigmap.Data["ca-bundle.crt"] == previousDefaultIngressCAConfigmap.Data["ca-bundle.crt"] {
+			return false, nil
+		}
+		return true, nil
+	})
+	if err != nil {
+		t.Logf("secret content=%v", string(secret.Data["tls.crt"]))
+		t.Fatalf("failed to observe update of default ingress CA certificate configmap: %v\noriginal=%v\ncurrent=%v", err, previousDefaultIngressCAConfigmap.Data["ca-bundle.crt"], defaultIngressCAConfigmap.Data["ca-bundle.crt"])
+	}
 }
 
 // TestIngressControllerScale exercises a simple scale up/down scenario.
@@ -543,8 +576,9 @@ func TestInternalLoadBalancer(t *testing.T) {
 	platform := infraConfig.Status.Platform
 
 	supportedPlatforms := map[configv1.PlatformType]struct{}{
-		configv1.AWSPlatformType:   {},
-		configv1.AzurePlatformType: {},
+		configv1.AWSPlatformType:      {},
+		configv1.AzurePlatformType:    {},
+		configv1.IBMCloudPlatformType: {},
 	}
 	if _, supported := supportedPlatforms[platform]; !supported {
 		t.Skip(fmt.Sprintf("test skipped on platform %q", platform))
